@@ -19,7 +19,7 @@ DEFAULT_TIMEOUT = 5
 DEVICE_NAME_MAX_LEN = 14
 
 
-ACL_PRIORITY_MAX = 32767
+ACL_PRIORITY_MAX = LR_POLICY_PRIORITY_MAX = 32767
 QOS_DSCP_MAX = 2 ** 6 - 1
 QOS_BANDWIDTH_MAX = 2 ** 32 - 1
 
@@ -28,5 +28,16 @@ NAT_DNAT = 'dnat'
 NAT_BOTH = 'dnat_and_snat'
 NAT_TYPES = (NAT_SNAT, NAT_DNAT, NAT_BOTH)
 
+POLICY_ACTION_ALLOW = 'allow'
+POLICY_ACTION_DROP = 'drop'
+POLICY_ACTION_REROUTE = 'reroute'
+POLICY_ACTION_TYPES = (POLICY_ACTION_ALLOW,
+                       POLICY_ACTION_DROP,
+                       POLICY_ACTION_REROUTE)
+
 PROTO_TCP = 'tcp'
 PROTO_UDP = 'udp'
+
+ROUTE_DISCARD = "discard"
+
+LOCALNET = 'localnet'
