@@ -40,11 +40,11 @@ class API(api.API, metaclass=abc.ABCMeta):
     def ls_del(self, switch, if_exists=False):
         """Delete logical switch 'switch' and all its ports
 
-        :param switch:   The name or uuid of the switch
-        :type switch:    string or uuid.UUID
-        :type if_exists: If True, don't fail if the switch doesn't exist
-        :type if_exists: boolean
-        :returns:        :class:`Command` with no result
+        :param switch:    The name or uuid of the switch
+        :type switch:     string or uuid.UUID
+        :param if_exists: If True, don't fail if the switch doesn't exist
+        :type if_exists:  boolean
+        :returns:         :class:`Command` with no result
         """
 
     @abc.abstractmethod
@@ -96,6 +96,17 @@ class API(api.API, metaclass=abc.ABCMeta):
         :returns: :class:`Command` with RowView result
         """
 
+    @abc.abstractmethod
+    def ls_get_localnet_ports(self, switch, if_exists=False):
+        """Get localnet ports on logical switch 'switch'
+
+        :param switch:    The name or uuid of the switch
+        :type switch:     string or uuid.UUID
+        :param if_exists: If True, don't fail if the switch doesn't exist
+        :type if_exists:  boolean
+        :returns: :class:`Command` with the RowView list result
+        """
+
     @abc.abstractmethod
     def acl_add(self, switch, direction, priority, match, action, log=False):
         """Add an ACL to 'switch'
@@ -695,9 +706,36 @@ class API(api.API, metaclass=abc.ABCMeta):
         :returns:               :class:`Command` with no result
         """
 
+    @abc.abstractmethod
+    def lrp_add_networks(self, port, networks, may_exist=False):
+        """Add a network to 'port'
+
+        :param port:      The name or uuid of the port
+        :type port:       string or uuid.UUID
+        :param networks:  One or more IP address/netmask to assign to the port
+        :type networks:   list or string
+        :param may_exist: If True, don't fail if the networks already exists
+        :type may_exist:  boolean
+        :returns:         :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def lrp_del_networks(self, port, networks, if_exists=False):
+        """Remove a network from 'port'
+
+        :param port:      The name or uuid of the port
+        :type port:       string or uuid.UUID
+        :param networks:  One or more IP address/netmask to remove from
+                          the port
+        :type networks:   list or string
+        :param if_exists: If True, don't fail if the networks doesn't exist
+        :type if_exists:  boolean
+        :returns:         :class:`Command` with no result
+        """
+
     @abc.abstractmethod
     def lr_route_add(self, router, prefix, nexthop, port=None,
-                     policy='dst-ip', may_exist=False):
+                     policy='dst-ip', may_exist=False, ecmp=False):
         """Add a route to 'router'
 
         :param router:    The name or uuid of the router
@@ -716,6 +754,10 @@ class API(api.API, metaclass=abc.ABCMeta):
         :type policy:     string, 'dst-ip' or 'src-ip'
         :param may_exist: If True, don't fail if the route already exists
         :type may_exist:  boolean
+        :param ecmp:      Enable ECMP support. If True adding routes with
+                          same IP prefix is allowed as long as the nexthop is
+                          different
+        :type ecmp:       boolean
         returns:          :class:`Command` with RowView result
         """
 
@@ -885,6 +927,88 @@ class API(api.API, metaclass=abc.ABCMeta):
     def lb_list(self):
         """Get the UUIDs of all load balanacers"""
 
+    @abc.abstractmethod
+    def lb_get(self, lb):
+        """Get load balancer for 'lb'
+
+        :returns: :class:`Command` with RowView result
+        """
+
+    @abc.abstractmethod
+    def lb_add_health_check(self, lb, vip, **options):
+        """Add health check for 'lb'
+
+        :param lb:      The name or uuid of a load balancer
+        :type lb:       string or uuid.UUID
+        :param vip:     A virtual IP
+        :type vip:      string
+        :param options: keys and values for the port 'options' dict
+        :type options:  key: string, value: string
+        :returns:       :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def lb_del_health_check(self, lb, hc_uuid, if_exists=False):
+        """Remove health check from 'lb'
+
+        :param lb:        The name or uuid of a load balancer
+        :type lb:         string or uuid.UUID
+        :param hc_uuid:   uuid of a health check
+        :type hc_uuid:    uuid.UUID
+        :param if_exists: If True, don't fail if the hc_uuid doesn't exist
+        :type if_exists:  boolean
+        :returns:         :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def lb_add_ip_port_mapping(self, lb, endpoint_ip, port_name, source_ip):
+        """Add IP port mapping to 'lb'
+
+        Maps from endpoint IP to a colon-separated pair of logical port name
+        and source IP, e.g. port_name:sourc_ip.
+
+        :param lb:          The name or uuid of a load balancer
+        :type lb:           string or uuid.UUID
+        :param endpoint_ip: IPv4 address
+        :type endpoint_ip:  string
+        :param port_name:   The name of a logical port
+        :type port_name:    string
+        :param source_ip:   IPv4 address
+        :type source_ip:    string
+        :returns:           :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def lb_del_ip_port_mapping(self, lb, endpoint_ip):
+        """Remove IP port mapping from 'lb'
+
+        :param lb:          The name or uuid of a load balancer
+        :type lb:           string or uuid.UUID
+        :param endpoint_ip: IPv4 address
+        :type endpoint_ip:  string
+        :returns:           :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def health_check_set_options(self, hc_uuid, **options):
+        """Set options to the 'health_check'
+
+        :param hc_uuid: uuid of the health check
+        :type hc_uuid:  uuid.UUID
+        :param options: keys and values for the port 'options' dict
+        :type options:  key: string, value: string
+        :returns:       :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def health_check_get_options(self, hc_uuid):
+        """Get the options for 'health_check'
+
+        :param hc_uuid: uuid of the health check
+        :type hc_uuid:  uuid.UUID
+        :returns:       :class:`Command` with dict result
+        """
+
     @abc.abstractmethod
     def lr_lb_add(self, router, lb, may_exist=False):
         """Add a load-balancer to 'router'
@@ -1277,3 +1401,72 @@ class API(api.API, metaclass=abc.ABCMeta):
         :type meter:   string or uuid.UUID
         :returns:      :class:`Command` with RowView result
         """
+
+    @abc.abstractmethod
+    def bfd_add(self, logical_port, dst_ip, min_tx=None, min_rx=None,
+                detect_mult=None, external_ids=None, options=None,
+                may_exist=False):
+        """Create a BFD entry
+
+        :param logical_port: Name of logical port where BFD engine should run.
+        :type logical_port:  str
+        :param dst_ip:       BFD peer IP address.
+        :type dst_ip:        str
+        :param min_tx:       This is the minimum interval, in milliseconds,
+                             that the local system would like to use when
+                             transmitting BFD Control packets, less any jitter
+                             applied. The value zero is reserved. Default value
+                             is 1000 ms.
+        :type min_tx:        Optional[int]
+        :param min_rx:       This is the minimum interval, in milliseconds,
+                             between received BFD Control packets that this
+                             system is capable of supporting, less any jitter
+                             applied by the sender. If this value is zero, the
+                             transmitting system does not want the remote
+                             system to send any periodic BFD Control packets.
+        :type min_rx:        Optional[int]
+        :param detect_mult:  Detection time multiplier.  The negotiated
+                             transmit interval, multiplied by this value,
+                             provides the Detection Time for the receiving
+                             system in Asynchronous mode. Default value is 5.
+        :type detect_mult:   Optional[int]
+        :param external_ids: Values to be added as external_id pairs.
+        :type external_ids:  Optional[Dict[str,str]]
+        :param options:      Reserved for future use.
+        :type options:       Optional[Dict[str,str]]
+        :param may_exist:    If True, update any existing BFD entry if it
+                             already exists.  Default is False which will raise
+                             an error if a BFD entry with same logical_port,
+                             dst_ip pair already exists.
+        :type may_exist:     Optional[bool]
+        :returns:            :class:`Command` with RowView result
+        """
+
+    @abc.abstractmethod
+    def bfd_del(self, uuid):
+        """Delete a BFD entry
+
+        :param uuid:   The uuid of the BFD entry
+        :type uuid:    uuid.UUID
+        :returns:      :class:`Command` with no result
+        """
+
+    @abc.abstractmethod
+    def bfd_find(self, logical_port, dst_ip):
+        """Find BFD entry.
+
+        :param logical_port: Name of logical port where BFD engine runs.
+        :type logical_port:  str
+        :param dst_ip:       BFD peer IP address.
+        :type dst_ip:        str
+        :returns:            :class:`Command` with List[Dict[str,any]] result
+        """
+
+    @abc.abstractmethod
+    def bfd_get(self, uuid):
+        """Get the BFD entry
+
+        :param uuid:   The uuid of the BFD entry
+        :type uuid:    uuid.UUID
+        :returns:      :class:`Command` with RowView result
+        """
